#!/bin/bash

# fix the container setup
export LD_LIBRARY_PATH=$LIBRARY_PATH:$LD_LIBRARY_PATH

# defined variables
USE_MPI="ON"
SOURCE_DIR="$HOME/walberla"
DIRS_TO_BUILD='tests/core apps/benchmarks/UniformGridCPU'

# derived variables 
export NUM_CORES=$(nproc --all)
# export MAX_BUILD_CORES=$(( $(awk '( $1 == "MemTotal:" ) { print $2 }' /proc/meminfo) / ( 4 * 1024 * 1024  ) ))
[[ $MAX_BUILD_CORES -lt $NUM_CORES ]] && export NUM_BUILD_CORES=$MAX_BUILD_CORES || export NUM_BUILD_CORES=$NUM_CORES

# cmake setup
CMAKE_BUILD_TYPE="Release"
WALBERLA_BUFFER_DEBUG="OFF"
WALBERLA_DOUBLE_ACCURACY="ON"
WALBERLA_ENABLE_GUI="OFF"
WALBERLA_BUILD_WITH_MPI=$USE_MPI
WALBERLA_BUILD_WITH_OPENMP="OFF"
WALBERLA_BUILD_WITH_METIS="OFF"
WALBERLA_BUILD_WITH_PARMETIS="OFF"
WALBERLA_BUILD_WITH_PYTHON="ON"
WALBERLA_BUILD_WITH_CODEGEN="ON"
WALBERLA_STL_BOUNDS_CHECKS="OFF"
WALBERLA_BUILD_WITH_CUDA="OFF"
WALBERLA_OPTIMIZE_FOR_LOCALHOST="ON"
WALBERLA_BUILD_WITH_FASTMATH="ON"
WALBERLA_BUILD_WITH_LTO="ON"

echo "Building walberla in $(pwd)"

cmake $SOURCE_DIR \
  -DWALBERLA_BUFFER_DEBUG=$WALBERLA_BUFFER_DEBUG \
  -DWALBERLA_BUILD_TESTS=ON \
  -DWALBERLA_BUILD_BENCHMARKS=ON \
  -DWALBERLA_BUILD_TUTORIALS=OFF \
  -DWARNING_ERROR=ON \
  -DWALBERLA_BUILD_WITH_MPI=$WALBERLA_BUILD_WITH_MPI \
  -DWALBERLA_BUILD_WITH_CUDA=$WALBERLA_BUILD_WITH_CUDA \
  -DWALBERLA_BUILD_WITH_PYTHON=$WALBERLA_BUILD_WITH_PYTHON \
  -DWALBERLA_BUILD_WITH_OPENMP=$WALBERLA_BUILD_WITH_OPENMP \
  -DCMAKE_BUILD_TYPE=$CMAKE_BUILD_TYPE \
  -DMPIEXEC_PREFLAGS=$MPIEXEC_PREFLAGS \
  -DWALBERLA_DOUBLE_ACCURACY=$WALBERLA_DOUBLE_ACCURACY \
  -DWALBERLA_BUILD_WITH_METIS=$WALBERLA_BUILD_WITH_METIS \
  -DWALBERLA_BUILD_WITH_PARMETIS=$WALBERLA_BUILD_WITH_PARMETIS \
  -DWALBERLA_ENABLE_GUI=$WALBERLA_ENABLE_GUI \
  -DWALBERLA_BUILD_WITH_CODEGEN=$WALBERLA_BUILD_WITH_CODEGEN \
  -DWALBERLA_STL_BOUNDS_CHECKS=$WALBERLA_STL_BOUNDS_CHECKS \
  -DWALBERLA_OPTIMIZE_FOR_LOCALHOST=$WALBERLA_OPTIMIZE_FOR_LOCALHOST \
  -DWALBERLA_BUILD_WITH_FASTMATH=$WALBERLA_BUILD_WITH_FASTMATH \
  -DWALBERLA_BUILD_WITH_LTO=$WALBERLA_BUILD_WITH_LTO

cmake . -LA

# actually build benchmarks
for dir_to_build in ${DIRS_TO_BUILD}; do
  make -C "$dir_to_build" -j $NUM_BUILD_CORES
done

# runing the core tests to ensure that everything is working
cd tests/core || exit 1
ctest -C $CMAKE_BUILD_TYPE --output-on-failure -j $NUM_CORES -T Test -R ReduceTest
