#!/bin/bash -l

cat << EOF
include:
  - "ci/pipeline.yml"
  # - "ci/global_variables.yml"
  # - "ci/common.yml"
  # - "ci/build.yml"
  # - "ci/test.yml"
  # - "ci/benchmark.yml"
  # - "ci/postprocessing.yml"

stages:
  - build
  - test
  - benchmark
  - postprocessing
  - final

EOF

HOSTLIST=$(sinfo -t idle,allocated -h --partition=work -o "%n")
# BENCHMARKS="mesa_pd uniformgridcpu phasefieldallencahn"
BENCHMARKS="uniformgridcpu"
# GPU_BENCHMARKS="uniformgridgpu phasefieldallencahngpu"
GPU_BENCHMARKS=""
HAS_GPU='medusa milan1'
NOT_TO_USE='aurora1 warmup phinally interlagos1 ivyep1 rome2 icx36 applem1studio'

for HOST in ${HOSTLIST}; do
  if [[ $NOT_TO_USE == *"$HOST"* ]]; then
       continue
  fi
  cat << EOF
build-$HOST:
  extends: .build
  variables:
    SLURM_NODELIST: $HOST
EOF
  if [[ $HAS_GPU == *"$HOST"* ]]; then
  cat << EOF
    WALBERLA_BUILD_WITH_CUDA: "ON"
EOF
  fi
  for BENCHMARK in ${BENCHMARKS}; do

  cat << EOF

benchmark_${BENCHMARK}_${HOST}:
  extends:
    - .benchmark_in_container
  dependencies:
    - build-$HOST
  needs:
    - job: build-$HOST
  variables:
    SLURM_NODELIST: $HOST
    SCRIPT: "$CI_PROJECT_DIR/benchmark_${BENCHMARK}.sh"

# upload_${BENCHMARK}_${HOST}:
#   extends:
#     - .upload_${BENCHMARK}
#   needs:
#     - job: benchmark_${BENCHMARK}_${HOST}
#   variables:
#     HOST: $HOST
EOF
  done
  if [[ $HAS_GPU == *"$HOST"* ]]; then
  for BENCHMARK in ${GPU_BENCHMARKS}; do

  cat << EOF
benchmark_${BENCHMARK}_${HOST}:
  extends:
    - .${BENCHMARK}_benchmark
  dependencies:
    - build-$HOST
  needs:
    - job: build-$HOST
  variables:
    SLURM_NODELIST: $HOST

# upload_${BENCHMARK}_${HOST}:
#   extends:
#     - .upload_${BENCHMARK}
#   needs:
#     - job: benchmark_${BENCHMARK}_${HOST}
#   variables:
#     HOST: $HOST
EOF
  done
  fi
done
# cat << EOF
#
# upload_pipeline_stats:
#   stage: final
#   tags:
#     - testcluster
#   variables:
#     NO_SLURM_SUBMIT: 1
#   when:
#     always
#   script:
#     - module load python/3.8-anaconda
#     - python3 upload_job_infos.py
#     - pip uninstall -y cb-util
# EOF
